# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`perlbrew`](#perlbrew): Installs perlbrew, perls and perl modules
* [`perlbrew::modules`](#perlbrewmodules): Installs perl modules into specified perlbrew perls.  It is called from
the perlbrew class, so it just needs hiera data to configure it.  cpanm does the install
of the modules.
* [`perlbrew::versions`](#perlbrewversions): Installs specified perls into perlbrew

## Classes

### <a name="perlbrew"></a>`perlbrew`

== class perlbrew

#### Examples

##### Basic usage

```puppet
class { 'perlbrew':
  install_root => /usr/local/perlbrew,
  owner => 'perl',
  group => 'perl',
  create_user => true,
  rc_files => ['/etc/profile.d/perlbrew.sh'],
}
```

#### Parameters

The following parameters are available in the `perlbrew` class:

* [`install_root`](#install_root)
* [`owner`](#owner)
* [`group`](#group)
* [`set_perms`](#set_perms)
* [`create_user`](#create_user)
* [`rc_files`](#rc_files)
* [`prereqs`](#prereqs)

##### <a name="install_root"></a>`install_root`

Data type: `String`

Directory to install the perlbrew installation, defaults to '/opt/perlbrew'

##### <a name="owner"></a>`owner`

Data type: `String`

Owner of the perlbrew files, defaults to 'perlbrew'

##### <a name="group"></a>`group`

Data type: `String`

Group of the perlbrew files, defaults to 'perlbrew'

##### <a name="set_perms"></a>`set_perms`

Data type: `Boolean`

Whether to set the install_root to these perms, defaults to true

##### <a name="create_user"></a>`create_user`

Data type: `Boolean`

Whether to create the system user of these perms, defaults to true

##### <a name="rc_files"></a>`rc_files`

Data type: `Array[String]`

A list of files to source the perlbrew environment from, defaults to ['/etc/profile.d/perlbrew.sh']

##### <a name="prereqs"></a>`prereqs`

Data type: `Array[String]`

Used internally - it's a list of binaries to check for for this class to work.

### <a name="perlbrewmodules"></a>`perlbrew::modules`

== Class: perlbrew::modules

#### Examples

##### Example Hiera Data

```puppet
perlbrew::modules::list:
  5.32.1:
  - Module::Build
  5.36.0:
  - Module::Build
  - String::ShortHostname
  - Dancer2
```

#### Parameters

The following parameters are available in the `perlbrew::modules` class:

* [`list`](#list)
* [`build_timeout`](#build_timeout)
* [`build_flags`](#build_flags)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of modules to be installed, specified per perl version installed

##### <a name="build_timeout"></a>`build_timeout`

Data type: `Integer`

How long puppet should wait in seconds before it times out the build and install of the module.
Defaults to 900 seconds.  Just be careful to make sure it is long enough to get all the
prereqs as well as they will all be included in the one build timeout unless they are separately
specified.

##### <a name="build_flags"></a>`build_flags`

Data type: `String`

The flags to pass to cpanm for the install of the modules, defaults to '--notest'

### <a name="perlbrewversions"></a>`perlbrew::versions`

== Class: perlbrew::versions

#### Examples

##### Example Hiera Data

```puppet
perlbrew::versions::installed:
- 5.32.1
- 5.36.0
```

#### Parameters

The following parameters are available in the `perlbrew::versions` class:

* [`installed`](#installed)
* [`build_timeout`](#build_timeout)
* [`build_flags`](#build_flags)
* [`purge_builds`](#purge_builds)

##### <a name="installed"></a>`installed`

Data type: `Array[String]`

A list of versions to be installed

##### <a name="build_timeout"></a>`build_timeout`

Data type: `Integer`

How long puppet should wait in seconds before it times out the build and install of the version.
Defaults to 900 seconds.

##### <a name="build_flags"></a>`build_flags`

Data type: `String`

The flags to pass to perlbrew for the install of the version, defaults to
'--notest -j %{facts.processorcount}'

##### <a name="purge_builds"></a>`purge_builds`

Data type: `Boolean`

Whether to purge the temporary build files after the install of the version, defaults to true

